pitchtools.expr_to_melodic_chromatic_interval_segment
=====================================================

.. autofunction:: abjad.tools.pitchtools.expr_to_melodic_chromatic_interval_segment.expr_to_melodic_chromatic_interval_segment
